 
/*
 -------------------------------------------------------------------------
 PURPOSE: Construct (i) individiual level sample and (ii) EMDAT for:
          Bekaert, E., Ruyssen, I. and S. Salomone (2020) Domestic and International Migration Intentions 
		  in Response to Environmental Stress: A Global Cross-Country Analysis
 ------------------------------------------------------------------------- 
 USAGE:   Start from Gallup World Polls data version 2013 (requires user access) for PART I and
		  from the EMDAT available in the replications files folder for PART II.
-------------------------------------------------------------------------- 
 Written by Els Bekaert, (UGent, UNU-CRIS), Ilse Ruyssen (UGent) and Sara Salomone (UNU-CRIS) August 2020 
--------------------------------------------------------------------------
*/

clear all
adopath + "U:/StataFiles"
global dir "U:/BekaertRuyssenSalomone/Replication files/"	
cd $dir
set matsize 11000
set maxvar 32000


//---------------------------- PART I. CONSTRUCTION GWP DATASET-----------------------------------------------------------
**********************
* A/ Select variables
**********************
use "The_Gallup_2013.dta", clear
rename WP* wp*
keep wave wpid countrynew YEAR_CALENDAR wp1220 wp1219 wp3117 wp4657 wp14 ///
INC_007 wp2319 wp1230 wp12 wp9042 wp1325 wp3120 wp9498 wp9455 ///
wp9499 wp4633 wp3331 wp3333 wp3334 wp3335 wp3336 wp6880 wp10252 wp10253 wp9500 wp9501 wp9502 wp9048 ///
wp85 wp4 wp36 wp37 wp38 wp39 wp40 wp43 wp44 ///
wp4651 wp4652 wp5244 wp5245 wp5249 wp5250 wp10256 wp10262 wp10263 wp10119 wp10257  ///
wp4649 wp11535 wp11538 wp11539 wp3469 wp3470 wp3471 wp3472 wp94 wp95                                 

rename countrynew origin  
rename YEAR_CALENDAR year
rename wp1220 age
rename wp1219 gender
rename INC_007 hhincpc
rename wp1230 children
rename wp12 hhsize

**********************
* B/ Recode variables
**********************
*** Rescale education (keep low skilled and combine medium skilled and high skilled into high skilled)
gen educ = .
replace educ = 0 if wp3117==1 
replace educ = 1 if wp3117==2 
replace educ = 2 if wp3117==3
drop wp3117

*** Seperate variables education
* secondary and tertiary education
gen secandterteduc =. 
replace secandterteduc = 1 if educ==1 | educ==2 
replace secandterteduc = 0 if educ==0 
label var secandterteduc "Higher education"
* primary education 
gen primaryeduc =. 
replace primaryeduc = 1 if educ==0
replace primaryeduc = 0 if educ==1 | educ==2
label var primaryeduc "Primary education"

*** Generate male dummy
gen male = .
replace male=0 if gender==2
replace male=1 if gender==1
label var male "Male"

*** Generate female dummy 
gen female = .
replace female=0 if gender==2
replace female=1 if gender==1
drop gender 

*** Rescale rural/urban (combine "A rural area or on a farm (1)" and "A small town or village (2)" 
*** into "rural (1)" and "A large city (3)" and "A suburb of a large city (6)" into "urban (2)" 
gen urban = .
replace urban = 0 if wp14==1 | wp14==2
replace urban = 1 if wp14==3 | wp14==6
drop wp14
label var urban "Urban"

*** Keep those aged 15+ and 60- and replace those who refused to answer (="100") and those who 99 and over (cause there's no specific age after 98, just "99+")
keep if age>=15
replace age=. if age>98
drop if age>60 

*** Create age categories
gen age1519 = 0
gen age2029 = 0
gen age3039 = 0
gen age4049 = 0
gen age5098 = 0

replace age1519 = 1 if age<20
replace age2029 = 1 if age>19 & age<30
replace age3039 = 1 if age>29 & age<40
replace age4049 = 1 if age>39 & age<50
replace age5098 = 1 if age>49 
label var age1519 "Aged 15 to 19"
label var age2029 "Aged 20 to 29"
label var age3039 "Aged 30 to 39"
label var age4049 "Aged 40 to 49"
label var age5098 "Aged 50 to 98"

*** Take logarithm of household income per capita
gen lhhincpc=ln(hhincpc)
label var lhhincpc "Household income per capita (ln)"


*** Create income categories 
//Note: the tresholds are computed manually rather than using the command "cut(lhhincpc), group (5)" as 
//      they were originally computed in a later stage of the sample construction 
gen incomecat = .
replace incomecat = 0 if lhhincpc > 0.8422909 & lhhincpc < 6.215131 
replace incomecat = 1 if lhhincpc > 6.215233 & lhhincpc < 7.10468
replace incomecat = 2 if lhhincpc > 7.104729 & lhhincpc < 7.949797
replace incomecat = 3 if lhhincpc > 7.949954 & lhhincpc < 8.851774
replace incomecat = 4 if lhhincpc > 8.851792 & lhhincpc < 14.50866

*** Replace number of children of those don't know (="98) or refused to answer (="99")
replace children=. if children==98 | children==99
label var children "Nr of children"

*** Create dummy for those born in the country of respondence 
gen native = 0
replace native = 1 if wp4657==1

*** Create network dummies
* HH member abroad
gen HHmabr = .
replace HHmabr = 1 if wp4633 == 1 
replace HHmabr = 0 if wp4633 == 2 | wp4633 == 3 | wp4633 == 4
* Friends or family member abroad
gen FFmabr = .
replace FFmabr = 1 if wp3333 == 1 
replace FFmabr = 0 if wp3333 == 2 | wp3333 == 3 | wp3333 == 4
egen mabr = rowmax(HHmabr FFmabr)
label var mabr "Network"

*** Environmental stress
tab wp10256
gen environprobl = .
replace environprobl = 1 if wp10256==1
replace environprobl = 0 if wp10256==2 
rename environprobl environstress
drop wp10256
label var environstress "Environmental stress" 

*** Household size 
label var hhsize "Nr of adults"

* Create wealth index developed by Dustmann and Okatenko (2014)
foreach k in wp37 wp38 wp39 wp40 wp43 wp44 {
	replace `k'=. if `k'>2
	replace `k'=0 if `k'==2 
}
polychoricpca wp37 wp39 wp40 wp43, score(pc_orig) nscore(1) 
rename pc_orig wealth

* Worldbank Country income categorisation  
merge m:1 origin using "Other Data sources/WBinc2010.dta", keep(match master) nogen
gen wbclass=. 
replace wbclass = 1 if wbclass2010=="Low income"
replace wbclass = 2 if wbclass2010=="Lower middle income"
replace wbclass = 3 if wbclass2010=="Upper middle income"
replace wbclass = 4 if wbclass2010=="High income: nonOECD" | wbclass2010=="High income: OECD"

*** Change names of specific countries
replace origin = "Bosnia and Herzegovina" if origin=="Bosnia Herzegovina"
replace origin = "Palestinian Territories" if origin=="Palestine" 
replace origin = "Somalia" if origin == "Somaliland"
replace origin = "Serbia and Montenegro" if origin == "Serbia" | origin == "Montenegro" | origin == "Kosovo"


**********************
* C/ Dummies for intending to migrate
**********************
// -----------------------------------------------------------------------------
// 1/ RECODE BILATERAL MIGRATION QUESTIONS
// -----------------------------------------------------------------------------
decode wp3120, generate(destp) 
gen destperm = substr(destp,5,.)
*** Identify destperm_pl country names (planning to move in next 12 months)
decode wp10253, generate(destp_pl ) 
gen destperm_pl = substr(destp_pl ,5,.)
*** Identify country of birth
decode wp9048, generate(cntrybth) 
gen cntrybirth = substr(cntrybth,5,.)

order cntrybirth destperm destperm_pl, after(o)

*** Set cntrybirth to missing if it mistakenly has a value
replace cntrybirth="" if cntrybirth=="(DK)" // 339 real changes made
replace cntrybirth="" if native==1 // 1989 real changes made 

*** Adjust names for specific countries
foreach k in cntrybirth destperm destperm_pl {
replace `k' = "Serbia and Montenegro" if `k' == "Serbia" | `k' == "Montenegro" | `k' == "Kosovo"
replace `k'="Antigua and Barbuda" if `k'=="Antigua & Barbuda"
replace `k' ="Congo Kinshasa" if `k' == "Congo (Kinshasa)"
replace `k'="St. Vincent and Grenadines" if `k'=="St. Vincent & Grenadines"
replace `k'="Trinidad and Tobago" if `k'=="Trinidad & Tobago"
}

// -----------------------------------------------------------------------------
// 2/ RECODE UNILATERAL MIGRATION QUESTIONS
// -----------------------------------------------------------------------------
*** Fill in missing responses to the unilateral migration questions when one of 
*** the follow up questions (plans or a destination) has been mentioned 
*** (ie interviewer failed to indicate "yes" for these respondents)
replace wp1325 = 1 if wp1325!=1 & wp10252==1 // permanent intention no but plan yes: 0 real changes made

*** Identify the country-waves where some people have missing values for the question 
*** on whether they want to move abroad while they do mention a destination and replace 
*** for these country-waves the missing value for wp1325 to zero when they did not mention
*** a destination (assuming that all those received the question AND do not want/plan to move)
preserve
	gen ow_in_perm_miss = 0
	replace ow_in_perm_miss = 1 if wp1325!=1 & destperm !=""
	keep if ow_in_perm_miss ==1
	keep origin wave year ow_in_perm_miss
	duplicates drop
	save "Temp/OriginWave_int_perm.dta",replace
restore
preserve
	gen ow_pl_perm_miss = 0
	replace ow_pl_perm_miss = 1 if wp10252!=1 & destperm_pl !=""
	keep if ow_pl_perm_miss ==1
	keep origin wave year ow_pl_perm_miss
	capture duplicates drop
	save "Temp/OriginWave_pl_perm.dta", replace
restore

merge m:1 origin wave using "Temp/OriginWave_int_perm.dta", keep(match master) nogen
merge m:1 origin wave using "Temp/OriginWave_pl_perm.dta", keep(match master) nogen

*Keep track of people who didn't provide a destination and have a missing value for the unilateral question
*while we know that other people in this survey wave and country did provide a destination (with unilateral question also missing)
*We will assume that all of them who did not provide a destination do not want to move
replace wp1325 = 5 if wp1325 ==. & destperm =="" & ow_in_perm_miss ==1 
replace wp10252 = 5 if wp10252 ==. & destperm_pl =="" & ow_pl_perm_miss ==1 

replace wp1325 = 1 if wp1325!=1 & (destperm !="" & destperm !=origin) | (destperm_pl !="" & destperm_pl != origin) // permanent intention no but destination mentioned
replace wp10252 = 1 if wp10252!=1 & destperm_pl!="" // permanent plan no but destination mentioned

*** Set destination to missing for those respondents who didn't properly answer the destination question 
foreach k in destperm destperm_pl {
	replace `k'="" if `k' == "(Refused)" | `k' == "(DK)" | `k' == "HOLD" | `k' == "hold" | `k' == "(None)" | `k' == "None" ///
	| `k' == "Other Country" | `k' == "African Country" | `k' == "Arab Country" | `k' == "Island Nations (11)" | `k' == "Other Islamic Country"
}

*** Set migration intention/plan to zero and destination to missing for those respondents who say they want to move but mention the country where 
*** they are interviewed as preferred destination (as we don't know which answer is true in this case: 258 people)
replace wp1325 = 0 if (wp1325==1 & destperm==origin) 
replace wp10252 = 0 if (wp10252==1 & destperm_pl==origin) 
foreach k in destperm destperm_pl {
	replace `k'="" if `k'==origin
}

// -----------------------------------------------------------------------------
// 3/ GENERATE MIGRATION VARIABLES
// -----------------------------------------------------------------------------
*QUESTION wp85 READS :In the next 12 months, are you likely or unlikely to move away from the city or area where you live?
gen move=.
replace move=1 if wp85==1
replace move=0 if wp85==2
label var move "likely to move away from the city or area where living in next 12m"

* UNILATERALLY desiring to move: 1 if respondent says he wants to migrate 
* permanently, 0 if he answers the question "do you want to move" with 2, 3 or 4
gen udm_perm = .
replace udm_perm = 1 if wp1325 == 1 
replace udm_perm = 0 if wp1325 == 2 | wp1325 == 3 | wp1325 == 4  | wp1325 == 5 
label var udm_perm "desire to migrate permanently to another country"

* BILATERALLY desiring to move to specific country: 1 if respondent says he wants to migrate 
* permanently and identifies a specific country, 0 if he does not indicate a country
gen bdm_perm = .
replace bdm_perm = 1 if destperm !="" 
replace bdm_perm = 0 if destperm =="" 
label var bdm_perm "desire to migrate permanently to another country and destination mentioned"

*** Create PLANNING to move dummies
* UNILATERALLY planning to move: 1 if respondent says he is planning to migrate 
* permanently abroad in the next 12 months, 0 if he does not 
gen udmpl_perm = .
replace udmpl_perm = 1 if wp10252 == 1 
replace udmpl_perm = 0 if wp10252 == 2 | wp10252 == 3 | wp10252 == 4 | wp10252 == 5 
label var udmpl_perm "plan to migrate permanently to another country in the next 12m "

* BILATERALLY planning to move to a country: 1 if respondent says he wants to and is planning to migrate 
* permanently to a specific country in the next 12 months, 0 if he does not mention a country
gen bdmpl1_perm = .
replace bdmpl1_perm = 1 if destperm_pl!=""
replace bdmpl1_perm = 0 if destperm_pl=="" 
label var bdmpl1_perm "plan to migrate permanently to another country in the next 12m and destination mentioned"

*** Rename variables accordingly
rename destperm dest_in
rename destperm_pl dest_pl
rename bdm_perm BMIG_in
rename bdmpl1_perm BMIG_pl
rename udm_perm UMIG_in
rename udmpl_perm UMIG_pl


// -----------------------------------------------------------------------------
// 4/ KEEP ONLY COUNTRY-WAVE PAIRS WHERE MIGRATION QUESTIONS WERE ASKED
// -----------------------------------------------------------------------------
*** Generate dummies to know where questions were asked
gen mig=0
replace mig=1 if BMIG_in==1
gen mig_pl=0
replace mig_pl=1 if BMIG_pl==1

preserve
collapse (mean) mig mig_pl, by (origin wave)
gen no_mig=0
replace no_mig=1 if mig==0
gen no_mig_pl=0
replace no_mig_pl=1 if mig_pl==0

keep origin wave no_mig no_mig_pl 
label variable no_mig "Missing intentions (if 1)"
label variable no_mig_pl "Missing plans (if 1)"
save "Temp/data_check.dta", replace
restore

merge m:1 origin wave using "Temp/data_check.dta", nogen

keep if no_mig==0 

*Merge with iso codes for origin and destination
merge m:1 dest_in using "Other Data sources/dest_in and iso_d.dta", keep(match master) nogen
merge m:1 origin using "Other Data sources/origin names and ISO codes.dta", keep(match master) nogen

*** Generate id variables 
egen o = group(origin)               
order o, before(origin)

save "Temp/Dataset_BSR_tempI.dta", replace

// -----------------------------------------------------------------------------
// 5/ ADD UNIQUE DESTINATION CODES
// -----------------------------------------------------------------------------
*** Match country names for destinations with those for origins
keep o origin
rename origin dest
rename o d
duplicates drop
save "Temp/OriginCodes.dta", replace

foreach k in _in _pl {
	use "Temp/Dataset_BSR_tempI.dta", clear
	keep dest`k'
	rename dest`k' dest
	duplicates drop
	drop if dest==""
	save "Temp/Dest`k'Names.dta", replace
}

*** Create one big file containing all destination names ever mentioned and create a unique destination code
use "Temp/OriginCodes.dta", clear
merge 1:1 dest using "Temp/Dest_inNames.dta", nogen
merge 1:1 dest using "Temp/Dest_plNames.dta"
sort d _merge dest
replace d = d[_n-1]+1 if missing(d) 
drop _merge
save "Temp/DestNames.dta", replace

*** Copy the file two times (for destinations for intentions and plans)
use "Temp/DestNames.dta", clear
rename d d_in
rename dest dest_in
save "Temp/Dest_inCodes.dta", replace
use "Temp/DestNames.dta", clear
rename d d_pl
rename dest dest_pl
save "Temp/Dest_plCodes.dta", replace

*** Add the unique destination codes to the Gallup data
use "Temp/Dataset_BSR_tempI.dta", clear
merge m:1 dest_in using "Temp/Dest_inCodes.dta"
drop _merge
merge m:1 dest_pl using "Temp/Dest_plCodes.dta"
drop if _merge == 2
drop _merge

order origin, before(o) 
order year wave wpid, after(o)
order UMIG_in UMIG_pl BMIG_in BMIG_pl d_in d_pl dest_in dest_pl mabr, after(urban)
order native, before(cntrybirth)

save "Temp/Dataset_BSR_tempII.dta", replace


**********************
* D/ DESTINATION CATEGORIES
**********************
gen finaldest= dest_pl
replace finaldest= dest_pl if UMIG_in==1 & UMIG_pl ==1 & dest_in!="" & dest_pl ==""
label var finaldest "where respondent ends up"

*merge m:1 origin using "Other Data sources/Countries and global regions.dta", keep(match master) nogen 

merge m:1 origin using "Other Data sources/UN regions.dta", nogen

*STAYERS WITHIN 12 MONTHS:
gen stayer12=.
replace stayer12=1 if move==0 
replace stayer12=0 if move==1 | (move==0 & UMIG_in==1 & UMIG_pl==1) 
label var stayer12 "people who move neither internally nor internationally in the next 12 months"

*** DOMESTIC MIGRANTS:
gen domesticmig=.
replace domesticmig=1 if (move==1 & UMIG_in==1 & UMIG_pl==0) | (move==1 & UMIG_in==0) 
replace domesticmig=0 if move==0 | (move==1 & UMIG_in==1 & UMIG_pl==1)
label var domesticmig "domestic migrants"

*** INTERNATIONAL MIGRANTS
*** Adjust some final inconsistent country names
replace finaldest="Somalia" if finaldest == "Somaliland region"
replace finaldest="Gambia" if finaldest == "The Gambia"
replace finaldest ="" if finaldest == "African Country"
replace finaldest ="" if finaldest == "US Hispanic"

merge m:1 finaldest using "Other Data sources/Destination subregion.dta", nogen

** Categorisation OECD-countries situation year 2010  
** Chile, Estonia, Slovenia & Israel in 2010  
gen OECD_dest=finaldest
foreach k in OECD_dest {
replace `k'="OECD" if `k'=="Australia" || `k'=="Austria" || `k'=="Belgium"|| `k'=="Canada"|| `k'=="Chile" || ///
`k'=="Czech Republic"|| `k'=="Denmark" || `k'=="Estonia" || `k'=="Finland" ||  `k'=="France" || ///
`k'=="Germany" || `k'=="Greece" || `k'=="Hungary" || `k'=="Iceland" || `k'=="Ireland" || `k'=="Israel" ||  ///
`k'=="Italy" || `k'=="Japan" ||  `k'=="Luxembourg" || `k'=="Mexico" ||`k'=="Netherlands" || ///
`k'=="New Zealand" || `k'=="Norway" || `k'=="Poland" || `k'=="Portugal" || `k'=="Slovenia" || ///
`k'=="South Korea" || `k'=="Spain" || `k'=="Sweden" || `k'=="Switzerland" || `k'=="Turkey" || ///
`k'=="United Kingdom" || `k'=="United States"

replace `k'="non-OECD" if `k' !="OECD"
}
replace OECD_dest="" if finaldest==""

tab subregion

** TOWARDS OECD
gen OECD=.
replace OECD = 1 if OECD_dest=="OECD" & finaldest !=""
replace OECD = 0 if (OECD_dest=="non-OECD" & finaldest !="") | stayer12==1 | domesticmig==1 | (subregion==subregion_d & finaldest !="")
label var OECD "destination OECD country"

*** INTRAREGIONAL
gen withinregion= . 
replace withinregion = 1 if subregion==subregion_d & finaldest !=""
replace withinregion = 0 if (subregion!=subregion_d & finaldest !="") | stayer12==1 | domesticmig==1 | OECD==1
label var withinregion "regional migrants"

*** OTHER COUNTRY 
gen rest=.   
replace rest = 1 if finaldest !="" & stayer12!=1 & domesticmig!=1 & withinregion!=1 & OECD!=1
replace rest = 0 if (finaldest !="" & (withinregion==1 | OECD==1 )) | stayer12==1 | domesticmig==1
label var rest "rest category destination"

*** FINAL CATEGORISATION DEPENDENT VARIABLE OR MULTINOMINAL LOGIT ESTIMATES 
gen dest= .
replace dest = 0 if stayer12==1   
replace dest = 1 if domesticmig==1  
replace dest = 2 if withinregion==1  
replace dest = 3 if OECD==1  
replace dest = 4 if rest==1   
label var dest "variable following destination migrant"

drop wp10119-wp11539 wp1325-wp39 wp40-wp9502 wbclass2010 ow_in_perm_miss ow_pl_perm_miss no_mig no_mig_pl wp9502 wave destp destp_pl cntrybth mig mig_pl

save "Dataset_BRS", replace

*** Erase temporary files
erase "Temp/Dataset_BSR_tempI.dta"
erase "Temp/Dataset_BSR_tempII.dta"



//___________________________________________________________________________________________________________________

//-------------------------------------- PART II. CONSTRUCTION EMDAT -------------------------------------------------------------------

use "Other Data sources/Data EMDAT public.dta", clear

gen year = real(Year) 
drop Year
gen EndminStartyear = Endyear - Startyear

encode Countryname, gen(countryname) 
drop Countryname
keep if Group=="Natural"   
drop if Subgroup=="Biological" 

*** Create variable for time series data
gen startmonth = ym(Startyear, Startmonth)   
gen endmonth = ym(Endyear, Endmonth)  
format startmonth endmonth %tm

*** Expand data between start and end dates 
gen duration = endmonth - startmonth + 1
gen disasterID = _n

expand duration
bysort disasterID : gen monthyear = startmonth + _n - 1

format monthyear* %tm 

keep if monthyear > tm(2008m12) & monthyear < tm(2011m1) 

keep countryname monthyear Type
order countryname monthyear 

*** Create dummy var's for extreme temp, drought and flood 
egen dis_nr = group(Type)
tab Type, gen(dis_)
rename dis_1 Drought
rename dis_2 Earthquake
rename dis_3 Extreme_temperature
rename dis_4 Flood
rename dis_5 Landslide
rename dis_6 Dry_mass_movement
rename dis_7 Storm
rename dis_8 Volcanic_activity
rename dis_9 Wildfire

collapse (sum) Drought Earthquake Extreme_temperature Flood Landslide Dry_mass_movement Storm Volcanic_activity Wildfire, by(countryname monthyear)
global VarsMonthlyFreq Drought Earthquake Extreme_temperature Flood Landslide Dry_mass_movement Storm Volcanic_activity Wildfire

egen disaster_freq = rowmax($VarsMonthlyFreq)
sum disaster_freq

//------------------------------------------
// Create full matrix and replace missings by zeros
//------------------------------------------
tsset countryname monthyear 
tsfill, full 

foreach k in $VarsMonthlyFreq disaster_freq {
	replace `k'=0 if `k'==.
}

//------------------------------------------
// Create overall disaster indicators: Occurrence 
// Note: this additional step is needed cause not taking the starting month but all potential months makes that some month-country pairs appear more than once,
//		 so that also by collapsing we get sometimes higher numbers than 1 (so these are not yet dummies)
//------------------------------------------
foreach k in $VarsMonthlyFreq {
	gen `k'_occ = 0
	replace `k'_occ = 1 if `k'>0
}

global VarsOccurrence Drought_occ Earthquake_occ Extreme_temperature_occ Flood_occ Landslide_occ Dry_mass_movement_occ Storm_occ Volcanic_activity_occ Wildfire_occ

egen disaster_occ = rowmax ($VarsOccurrence)

//------------------------------------------
// Create lags
//------------------------------------------
foreach k in $VarsOccurrence disaster_occ $VarsMonthlyFreq disaster_freq {
	forvalues i=1(1)12 {
		qui bysort countryname: gen `k'L`i'=L`i'.`k'
	}
}

//------------------------------------------
// Cumulate variables 
// Note: here we take the original variables, not the dummies
// 		 Plus we only keep the cumulative variable over 12 months, we don't need the other ones
//------------------------------------------
// Number (frequency) of disasters
foreach k in $VarsMonthlyFreq  {
	egen `k'_freqC12=rowtotal(`k'L1-`k'L12)
}
egen disaster_freqC12=rowtotal(disaster_freqL1-disaster_freqL12)

// Occurrence of disasters
foreach k in $VarsOccurrence disaster_occ {
	egen `k'C12=rowmax(`k'L1-`k'L12)
}

sum *C12

keep countryname monthyear *C12
sum _all

decode countryname, gen(Countryname)
drop countryname
order Countryname monthyear

*** Merge prepare 
replace Countryname = "Bolivia" if Countryname=="Bolivia (Plurinational State of)"
replace Countryname = "Czech Republic" if Countryname=="Czech Republic (the)"
replace Countryname = "Dominican Republic" if Countryname=="Dominican Republic (the)"
replace Countryname = "South Korea" if Countryname=="Korea (the Republic of)"
replace Countryname = "Moldova" if Countryname=="Moldova (the Republic of)"
replace Countryname = "Netherlands" if Countryname=="Netherlands (the)"
replace Countryname = "Niger" if Countryname=="Niger (the)"
replace Countryname = "Palestinian Territories" if Countryname=="Palestine, State of"
replace Countryname = "Philippines" if Countryname=="Philippines (the)"
replace Countryname = "Russia" if Countryname=="Russian Federation (the)"
replace Countryname = "Sudan" if Countryname=="Sudan (the)"
replace Countryname = "Tanzania" if Countryname=="Tanzania, United Republic of"
replace Countryname = "United Arab Emirates" if Countryname=="United Arab Emirates (the)"
replace Countryname = "United Kingdom" if Countryname=="United Kingdom of Great Britain and Northern Ireland (the)"
replace Countryname = "United States" if Countryname=="United States of America (the)"
replace Countryname = "Venezuela" if Countryname=="Venezuela (Bolivarian Republic of)"
replace Countryname = "Vietnam" if Countryname=="Viet Nam"
replace Countryname = "Comoros" if Countryname=="Comoros (the)"
replace Countryname = "Macedonia" if Countryname=="Macedonia (the former Yugoslav Republic of)"
replace Countryname = "Syria" if Countryname=="Syrian Arab Republic"
replace Countryname = "Taiwan" if Countryname=="Taiwan (Province of China)"
replace Countryname = "Serbia and Montenegro" if Countryname=="Serbia Montenegro"
replace Countryname = "Congo Kinshasa" if Countryname=="Congo (the Democratic Republic of the)"
replace Countryname = "Congo Brazzaville" if Countryname=="Congo (the)"
replace Countryname = "Iran" if Countryname=="Iran (Islamic Republic of)"
replace Countryname = "Laos" if Countryname=="Lao People's Democratic Republic (the)"
 
rename Countryname origin 

save "Temp/EMDAT_reg.dta", replace





