
/*
 -------------------------------------------------------------------------
 PURPOSE: Merge individiual level data with country characteristics and run 
 		  estimations. This dofile generates the estimation tables for:
          Bekaert, E., Ruyssen, I. and S. Salomone (2020) Domestic and 
		  International Migration Intentions in Response to Environmental Stress:
		  A Global Cross-Country Analysis.  Journal of Demographic Economics.
 ------------------------------------------------------------------------- 
 USAGE:   Start from the sample constructed from the Gallup World Polls (see
 		  dofile "Data construction categorisation.do")
-------------------------------------------------------------------------- 
 Written by Els Bekaert, (UGent, UNU-CRIS), Ilse Ruyssen (UGent) and Sara Salomone (UNU-CRIS) October 2017
--------------------------------------------------------------------------
*/

clear all 
adopath + "U:/StataFiles"
global dir "U:/BekaertRuyssenSalomone/Replication files/"	
cd $dir
set matsize 11000

use "Dataset_BRS.dta", clear

// -----------------------------------------------------------------------------
// 							 SETTINGS 
// -----------------------------------------------------------------------------
global controls "age2029 age3039 age4049 age5098 male secandterteduc urban lhhincpc hhsize children mabr i.o"
global controls2 "age2029 age3039 age4049 age5098 male secandterteduc urban hhsize children mabr i.o" // no income

// -----------------------------------------------------------------------------
// 							 DESCRIPTIVES 
// -----------------------------------------------------------------------------
* Table 1 JODE-paper
mlogit dest environstress $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T1a
tab dest if e(sample)

*Table 2 JODE-paper
est restore T1a
* Overall
sum environstress age male secandterteduc urban lhhincpc hhsize children mabr if e(sample)==1
* Stay
sum environstress age male secandterteduc urban lhhincpc hhsize children mabr if dest==0 & e(sample)==1
* Domestic
sum environstress age male secandterteduc urban lhhincpc hhsize children mabr if dest==1 & e(sample)==1
* Intraregional
sum environstress age male secandterteduc urban lhhincpc hhsize children mabr if dest==2 & e(sample)==1
* OECD
sum environstress age male secandterteduc urban lhhincpc hhsize children mabr if dest==3 & e(sample)==1


// -----------------------------------------------------------------------------
// 							 ESTIMATIONS 
// -----------------------------------------------------------------------------

* Benchmark Estimations (Table 3 JODE-paper)
mlogit dest environstress $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T3b
margins, dydx(environstress) post vce(unconditional) 
est store ME1
mlogit dest $controls if e(sample), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T3a
esttab T3a T3b using "Table3.tex", label title("Mlogit with GWP climate vars") mtitles("Controls" "Envrionstress")  ///
eform unstack nodepvars replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")
esttab ME1 using "AME.tex", label title("Impact of environ mental stress and traditional controls - Marginal effects") mtitles ///
nodepvars replace star(* 0.10 ** 0.05 *** 0.01) nonumbers t(2)  nogaps scalars("ll Log likelihood" "chi2 Wald Chi$^2$" "df_m Dof" "p Prob > Chi$^2$") obslast addnotes("Standard errors are robust to heteroskedasticity and clustered across origins.")

* Modified Samples (Table 4 JODE-paper)
mlogit dest environstress $controls if (native==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4a
mlogit dest environstress $controls if (secandterteduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4b
mlogit dest environstress $controls if (primaryeduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4c
mlogit dest environstress $controls if (urban==0), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4d
mlogit dest environstress $controls if (urban==0 & primaryeduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4e
mlogit dest environstress $controls if (urban==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4f
mlogit dest environstress $controls if (female==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4g
mlogit dest environstress $controls if (incomecat==4), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4h
mlogit dest environstress $controls if (incomecat==0), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4i
mlogit dest environstress $controls if (incomecat==0 & primaryeduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T4j
esttab T4a T4b T4c T4d T4e T4f T4g T4h T4i T4j using "Table4.tex", label title("Mlogit estimations modified samples") mtitles("Natives" "HS" " LS" "Rural" "Rural LS" "Urban" "Female" "Rich" "Poor" "Poor LS") ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

* Interactions: poverty constraints (Footnote 26 JODE-paper)
gen envstressxwealth = environstress*wealth
mlogit dest environstress envstressxwealth $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T2a
esttab T2a using "Wealth.tex", label title("Mlogit estimations with interaction Wealth") mtitles("Wealth")  ///
eform nodepvars replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

* Benchmark by development level (Table 5 JODE-paper)
mlogit dest environstress $controls if wbclass==1, rrr robust cluster(o) base(0) difficult iter(200)  tech(dfp nr)
est sto T5a 
mlogit dest environstress $controls if wbclass==2, rrr robust cluster(o) base(0) difficult iter(200)  tech(dfp nr)
est sto T5b
mlogit dest environstress $controls if wbclass==3, rrr robust cluster(o) base(0) difficult iter(200)  tech(dfp nr)
est sto T5c
mlogit dest environstress $controls if wbclass==4, rrr robust cluster(o) base(0) difficult iter(200)  tech(dfp nr)
est sto T5d
esttab T5a T5b T5c T5d using "Table5.tex", label title("Mlogit estimations by development level") mtitles("L" "LM" "UM" "H") ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

* Benchmark by geographic region (Table 6 JODE-paper)
mlogit dest environstress $controls if regionUN=="Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T6a
mlogit dest environstress $controls if regionUN=="Latin America and the Caribbean", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T6b
mlogit dest environstress $controls if regionUN=="Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T6c
mlogit dest environstress $controls if regionUN=="Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T6d 
mlogit dest environstress $controls if regionUN=="Northern America", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr) //0 observations
est sto T6e
mlogit dest environstress $controls if regionUN=="Oceania", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T6f
esttab T6a T6b T6c T6d T6e T6f using "Table6.tex", label title("Mlogit estimations by region") mtitles("Africa" "LAC" "Asia" "Europe" "North America" "Oceania")  ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

* Modified samples by geographic region (Table 7 JODE-paper)
mlogit dest environstress $controls if (primaryeduc==1 & regionUN=="Africa"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7a
mlogit dest environstress $controls if (urban==0 & regionUN=="Africa"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7b
mlogit dest environstress $controls if (urban==0 & primaryeduc==1 & regionUN=="Africa"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7c
mlogit dest environstress $controls if (primaryeduc==1 & regionUN=="Asia"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7d
mlogit dest environstress $controls if (urban==0  & regionUN=="Asia"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7e
mlogit dest environstress $controls if (urban==0 & primaryeduc==1 & regionUN=="Asia"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7f
mlogit dest environstress $controls if (primaryeduc==1 & regionUN=="Latin America and the Caribbean"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7g
mlogit dest environstress $controls if (urban==0 & regionUN=="Latin America and the Caribbean"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7h
mlogit dest environstress $controls if (urban==0 & primaryeduc==1 & regionUN=="Latin America and the Caribbean"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto T7i
esttab T7a T7b T7c T7d T7e T7f T7g T7h T7i using "Table7.tex", label title("Mlogit estimations modified samples by region") mtitles("LS" "Rural" "Rural LS" "LS" "Rural" "Rural LS" "LS" "Rural" "Rural LS") ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")


* // Appendix A // 

* Observations by country  (Appendix Table A.1 JODE-paper)
mlogit dest environstress $controls , rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
tab origin if e(sample)

* Marginal effects benchmark and by region (Appendix Table A.2 JODE-paper)
mlogit dest environstress $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA2_1
margins, dydx(environstress) post vce(unconditional) 
est store ME1
mlogit dest environstress $controls if regionUN=="Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA2_2
margins, dydx(environstress) post vce(unconditional) 
est store ME2
mlogit dest environstress $controls if regionUN=="Latin America and the Caribbean", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA2_3
margins, dydx(environstress) post vce(unconditional) 
est store ME3
mlogit dest environstress $controls if regionUN=="Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA2_4
margins, dydx(environstress) post vce(unconditional) 
est store ME4
mlogit dest environstress $controls if regionUN=="Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA2_5 
margins, dydx(environstress) post vce(unconditional) 
est store ME5
mlogit dest environstress $controls if  (regionUN=="Northern America" | regionUN=="Oceania"), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr) //0 observations
est sto TA2_6
margins, dydx(environstress) post vce(unconditional) 
est store ME6
esttab ME1 ME2 ME3 ME4 ME5 ME6 using "TableA2.tex", label title("Impact of environmental stress - Marginal effects \label{TableME}") mtitles("All regions" "Africa" "LAC" "Asia" "Europe" "N-Am/Oceania") /// 
nodepvars replace star(* 0.10 ** 0.05 *** 0.01) nonumbers t(2)  nogaps scalars("ll Log likelihood" "chi2 Wald Chi$^2$" "df_m Dof" "p Prob > Chi$^2$") obslast addnotes("Standard errors are robust to heteroskedasticity and clustered across origins.")
* Predictive margins
est restore T1_a
margins environstress, vce(unconditional) 

* Control for indirect effect through income (Appendix Table A.3 JODE-paper)
mlogit dest environstress $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA3a
mlogit dest environstress $controls2, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA3b
esttab TA3a TA3b using "TableA3.tex", label title("Mlogit with GWP climate vars") mtitles("Benchmark" "Without income")  ///
eform unstack nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

* Subcontinental regions 
*** Asia (Appendix Table A.4 JODE-paper)
mlogit dest environstress $controls if subregion=="Central Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA4a
mlogit dest environstress $controls if subregion=="Eastern Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA4b
mlogit dest environstress $controls if subregion=="South-Eastern Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA4c
mlogit dest environstress $controls if subregion=="Southern Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA4d 
mlogit dest environstress $controls if subregion=="Western Asia", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA4e
esttab TA4a TA4b TA4c TA4d TA4e using "TableA4.tex", label title("Mlogit by subregion: Asia") mtitles("Central Asia" "Eastern Asia" "South-Eastern Asia" "Southern Asia" "Western Asia")  ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

*** LAC  (Appendix Table A.5 JODE-paper)
mlogit dest environstress $controls if subregion=="Caribbean", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA5a
mlogit dest environstress $controls if subregion=="Central America", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA5b
mlogit dest environstress $controls if subregion=="South America", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA5c
esttab TA5a TA5b TA5c using "TableA5.tex", label title("Mlogit by subregion: LAC") mtitles("Caribbean" "Central America" "South America")  ///
eform nodepvars pr2  replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

*** Africa  (Appendix Table A.6 JODE-paper)
mlogit dest environstress $controls if subregion=="Eastern Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA6a 
mlogit dest environstress $controls if subregion=="Middle Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA6b 
*mlogit dest environstress $controls if subregion=="Northern Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr) // 0 Observations 
*est sto TA6c
mlogit dest environstress $controls if subregion=="Southern Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA6d
mlogit dest environstress $controls if subregion=="Western Africa", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA6e
esttab TA6a TA6b TA6d TA6e using "TableA6.tex", label title("Mlogit by subregion: Africa") mtitles("Eastern Africa" "Middle Africa" "Northern Africa" "Southern Africa" "Western Africa")  ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")

*** Europe - Northern America - Australia/NZ  (Appendix Table A.7 JODE-paper)
mlogit dest environstress $controls if subregion=="Eastern Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7a
mlogit dest environstress $controls if subregion=="Northern Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7b
mlogit dest environstress $controls if subregion=="Southern Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7c 
mlogit dest environstress $controls if subregion=="Western Europe", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7d
mlogit dest environstress $controls if subregion=="Northern America", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7e
mlogit dest environstress $controls if subregion=="Australia/New Zealand", rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA7f
esttab TA7a TA7b TA7c TA7d TA7e TA7f using "TableA7.tex", label title("Mlogit by subregion: non-developing") mtitles("Eastern Europe" "Northern Europe" "Southern Europe" "Western Europe" "Northern America" "Australia/NZ")  ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")


* // SENSITIVITY ANALYSES: EM-DAT (Appendix B)// 
keep if year==2010  
gen month = month(wp4)
gen monthyear = ym(year, month) 
format monthyear %tm
merge m:1 origin monthyear using "Temp/EMDAT_reg.dta", keep(match master) nogen
foreach k of varlist Drought_freqC12-disaster_occC12 {
	replace `k'=0 if `k'==. 
}

* Benchmark environmental disasters occurrence  (Appendix Table A.8 JODE-paper)
mlogit dest environstress $controls , rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA8a
keep if e(sample)
mlogit dest disaster_occC12 $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA8b
esttab TA8a TA8b using "TableA8.tex", label title("Mlogit with EM-DAT") mtitles("Benchmark" "External measures EM-DAT")  ///
eform unstack nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")


* Both self-reported and actual occurrence + types of environmental hazards   (Appendix Table A.9 JODE-paper)
mlogit dest environstress disaster_occC12 $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA9a
mlogit dest environstress Drought_occC12 Extreme_temperature_occC12 Flood_occC12 Storm_occC12 Wildfire_occC12 $controls, rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA9b
esttab TA9a TA9b using "TableA9.tex", label title("Mlogit with EMDAT climate vars") mtitles("Drought, flood and extreme temperature")  ///
eform unstack nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")


* by subsamples individual characteristics  (Appendix Table A.10 JODE-paper)
mlogit dest environstress disaster_occC12 $controls if (native==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10a
mlogit dest environstress disaster_occC12 $controls if (secandterteduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10b
mlogit dest environstress disaster_occC12 $controls if (primaryeduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10c
mlogit dest environstress disaster_occC12 $controls if (urban==0), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10d
mlogit dest environstress disaster_occC12 $controls if (urban==0 & primaryeduc==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10e
mlogit dest environstress disaster_occC12 $controls if (urban==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10f
mlogit dest environstress disaster_occC12 $controls if (female==1), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10g
mlogit dest environstress disaster_occC12 $controls if (incomecat==4), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10h
mlogit dest environstress disaster_occC12 $controls if (incomecat==0), rrr robust cluster(o)  base(0) difficult iter(200)  tech(dfp nr)
est sto TA10i
esttab TA10a TA10b TA10c TA10d TA10e TA10f TA10g TA10h TA10i using "TableA10.tex", label title("mlogit estimations EM-DAT subsamples") mtitles("Natives" "High skilled" " Primary" "Rural" "Rural Primary" "Urban" "Female" "Rich" "Poor") ///
eform nodepvars pr2 replace star(* 0.10 ** 0.05 *** 0.01) drop(*.o) nonumbers t(2) b(3) nogaps obslast addnotes("Standard errors are robust and clustered across origins.")











